.. _Cylinder class:

The Cylinder class
------------------

.. currentmodule:: rockverse.region

.. autoclass:: Cylinder

   .. rubric:: Attributes

   .. autoattribute:: p
   .. autoattribute:: v
   .. autoattribute:: r
   .. autoattribute:: l
   .. autoattribute:: region

   .. rubric:: Methods

   .. automethod:: contains_point
